# cat ~/oracion.txt | java -jar ixa-pipes-1.1.1/ixa-pipe-tok-1.8.5-exec.jar tok -l es | java -jar ixa-pipes-1.1.1/ixa-pipe-pos-1.5.1-exec.jar tag -m ixa-pipes-1.1.1/morph-models-1.5.0/es/es-pos-perceptron-autodict01-ancora-2.0.bin -lm ixa-pipes-1.1.1/morph-models-1.5.0/es/es-lemma-perceptron-ancora-2.0.bin

if ($tagger =~ /ixa|all/){
	my %keylang = (
		'spanish' => {
			'abbr' => 'es',
			'tok' => 'es-pos-perceptron-autodict01-ancora-2.0.bin',
			'pos' => 'es-lemma-perceptron-ancora-2.0.bin',
		},
		'english' => {
			'abbr' => 'en',
			'tok' => 'en-pos-perceptron-autodict01-conll09.bin',
			'pos' => 'en-lemma-perceptron-conll09.bin',
		},
	);
	# Path of IXA pipes
	my $ixa = $tagpath.'ixa-pipes-1.1.1';
	my $ixatok = $ixa.'/ixa-pipe-tok-1.8.5-exec.jar';
	my $ixapos = $ixa.'/ixa-pipe-pos-1.5.1-exec.jar';
	my $abbrlang = $keylang{$language}{'abbr'};
	my $models = $ixa.'/morph-models-1.5.0/'.$abbrlang;
	my $output = $tmpath.'/'.$id.'-ixa.tag';
	my $command = "cat $inputfile | $java -jar $ixatok tok -l $abbrlang | $java -jar $ixapos tag -m $models/$keylang{$language}{'tok'} -lm $models/$keylang{$language}{'pos'} > $output";
	
	# Messages for command line
	if ($verbose){
		&loading("IXA-pipes", $command);
	}
	# Execute tagging operation
	&perftime($command);
	
	# IXA-pipes' output is formatted in NAF format. This is 
	# XML-like, so we need make some modifications to obtain 
	# a CSV or HTML format. So, in this case, you will have 
	# three format available: NAF with txt option, CSV with csv 
	# option and HTML with html option.
	if ($format eq 'txt'){
		my $mv = "mv $output $outpath";
		warn "Moving output file: [$mv]\n";
		system($mv);
	}elsif ($format eq 'csv' || $format eq 'html'){
		my ($out, $form, $lemma, $pos, $morph, $type);
		$out = "Form\tLemma\tPOS\tMorphofeat\tType\n" if ($format eq 'csv');
		$out = "<tr><th>Form</th><th>Lemma</th><th>POS</th><th>Morphofeat</th><th>Type</th></tr>\n" if ($format eq 'html');
		open (IXA, '<', $output);
		while (my $line = <IXA>){
			chomp $line;
			if ($line =~ /^ {4}<!--(.+)-->$/){
				$form = $1;
				$out .= "$form\t" if ($format eq 'csv');
				$out .= "<tr><td>$form</td>" if ($format eq 'html');
			}
			if ($line =~ /<term id="[^"]+" type="([^"]+)" lemma="([^"]+)" pos="([^"]+)" morphofeat="([^"]+)">/){
				$lemma = $2;
				$pos = $3;
				$morph = $4;
				$type = $1;
				$out .= "$lemma\t$pos\t$morph\t$type\n" if ($format eq 'csv');
				$out .= "<td>$lemma</td><td>$pos</td><td>$morph</td><td>$type</td></tr>\n" if ($format eq 'html');
			}
		}
		close IXA;
		if ($format eq 'csv'){
			open (OUT, '>', $outpath.'/'.$id.'-ixa.tag');
			print OUT $out;
			close OUT;
			unlink $output;
		}elsif ($format eq 'html'){
			print "<pre>$perftime seconds elapsed.</pre>\n";
			print "<div class='table-responsive'>$tableprop\n";
			print $out;
			print "</table></div>\n";
			warn "Removing [$output]\n" if ($unlink && $verbose);
			# If you use --unlink option, we will remove temporary file.
			unlink $output if ($unlink);
		}
	}
}

1;
